import request from '@/config/axios'

// 门墩儿-企业工商信息 VO
export interface EnterpriseBusinessVO {
  id: number // id
  enterpriseId: number // 企业id
  code: string // 统一社会信用代码
  name: string // 企业名称
  type: string // 企业类型
  area: string // 所属地区
  address: string // 注册地址
  representative: string // 法定代表人
  establishmentTime: Date // 成立时间
  registeredCapital: string // 注册资金
  approvalTime: string // 核准日期
  formerName: string // 曾用名
  industry: string // 所属行业
  registrationAuthority: string // 注册机关
  businessStatus: string // 经营状态
  businessTerm: string // 营业期限
  businessScope: string // 经营范围
}

// 门墩儿-企业工商信息 API
export const EnterpriseBusinessApi = {
  // 查询门墩儿-企业工商信息分页
  getEnterpriseBusinessPage: async (params: any) => {
    return await request.get({ url: `/menduner/system/enterprise-business/page`, params })
  },

  // 查询门墩儿-企业工商信息详情
  getEnterpriseBusiness: async (id: number) => {
    return await request.get({ url: `/menduner/system/enterprise-business/get?id=` + id })
  },

  // 新增门墩儿-企业工商信息
  createEnterpriseBusiness: async (data: EnterpriseBusinessVO) => {
    return await request.post({ url: `/menduner/system/enterprise-business/create`, data })
  },

  // 修改门墩儿-企业工商信息
  updateEnterpriseBusiness: async (data: EnterpriseBusinessVO) => {
    return await request.put({ url: `/menduner/system/enterprise-business/update`, data })
  },

  // 删除门墩儿-企业工商信息
  deleteEnterpriseBusiness: async (id: number) => {
    return await request.delete({ url: `/menduner/system/enterprise-business/delete?id=` + id })
  },

  // 导出门墩儿-企业工商信息 Excel
  exportEnterpriseBusiness: async (params) => {
    return await request.download({ url: `/menduner/system/enterprise-business/export-excel`, params })
  }
}