import request from '@/config/axios'

export const talentHotelApi = {
	// 标签列表
	getTalentTagList: async () => {
		return await request.get({ 
			url: `/api/parse/get-talent-tag-list`, 
			baseURL: import.meta.env.VITE_BASE_URL 
		})
	},

	// 创建人才标签
	createTalentTag: async (data: any) => {
		return await request.post({ 
			url: `/api/parse/create-talent-tag`, 
			data, 
			baseURL: import.meta.env.VITE_BASE_URL
		})
	},

	// 更新人才标签
	updateTalentTag: async (tag_id: number, data: any) => {
		return await request.put({ 
			url: `/api/parse/update-talent-tag/${tag_id}`, 
			data, 
			baseURL: import.meta.env.VITE_BASE_URL 
		})
	},

	// 删除人才标签
	deleteTalentTag: async (tag_id: number) => {
		return await request.delete({ 
			url: `/api/parse/delete-talent-tag/${tag_id}`, 
			baseURL: import.meta.env.VITE_BASE_URL 
		})
	}
}

// 酒店集团品牌管理
export const talentHotelGroupBrandApi = {
	// 获取所有品牌记录
	getData: async () => {
		return await request.get({ 
			url: `/api/parse/get-hotel-group-brands-list`, 
			baseURL: import.meta.env.VITE_BASE_URL 
		})
	},

	// 查询指定品牌记录(根据ID查询指定品牌记录)
	getDetail: async (brand_id: number) => {
		return await request.get({ 
			url: `/api/parse/query-hotel-group-brands/${brand_id}`, 
			baseURL: import.meta.env.VITE_BASE_URL 
		})
	},

	// 新增品牌记录
	create: async (data: any) => {
		return await request.post({ 
			url: `/api/parse/add-hotel-group-brands`, 
			data, 
			baseURL: import.meta.env.VITE_BASE_URL
		})
	},

	// 更新品牌记录
	update: async (brand_id: number, data: any) => {
		return await request.put({ 
			url: `/api/parse/update-hotel-group-brands/${brand_id}`, 
			data, 
			baseURL: import.meta.env.VITE_BASE_URL 
		})
	},

	// 删除品牌记录
	delete: async (brand_id: number) => {
		return await request.delete({ 
			url: `/api/parse/delete-hotel-group-brands/${brand_id}`, 
			baseURL: import.meta.env.VITE_BASE_URL 
		})
	}
}
